@@ -40,7 +40,8 @@ int main(int argc, char ** argv)
                      QStringLiteral(BOMBER_VERSION_STRING),
                      i18n("Arcade bombing game"),
                      KAboutLicense::GPL, i18n("(C) 2007 John-Paul Stanford"),
-                     QString(), QStringLiteral("jp@stanwood.org.uk"));
+                     QString(),
+                     QStringLiteral("https://apps.kde.org//bomber"));
     about.addAuthor(i18n("John-Paul Stanford"), QString(),
                     QStringLiteral("jp@stanwood.org.uk"));
     about.addAuthor(i18n("Mehmet Emre"), i18n("Porting to QGraphicsView."),
